@@ -279,6 +279,8 @@ qx.Class.define("callbackery.ui.form.Auto", {
         _model : null,
         _settingData : false,
         _typeMap : null,
+        _keyToFormKey: null,
+        _formKeyToKey: null,
 
 
         /**
@@ -375,6 +377,9 @@ qx.Class.define("callbackery.ui.form.Auto", {
 
             for (var key in data) {
                 var formKey = this._keyToFormKey[key];
+                if (!formKey) {
+                    continue;
+                }
                 var upkey = qx.lang.String.firstUp(formKey);
                 var setter = 'set' + upkey;
                 var getter = 'get' + upkey;
